[![Build Status](https://travis-ci.org/EMBL-Hentze-group/htseq-clip.svg?branch=master)](https://travis-ci.org/EMBL-Hentze-group/htseq-clip)    
![GitHub](https://img.shields.io/github/license/EMBL-Hentze-group/htseq-clip)

# htseq-clip

htseq-clip is a toolset for the analysis of eCLIP/iCLIP datasets. 
This python package can be used to generate files necessary for 
data analysis using the companion R/Bioconductor package [DEWSeq](https://bioconductor.org/packages/release/bioc/html/DEWSeq.html).

URL: https://github.com/EMBL-Hentze-group/htseq-clip

Documentation: https://htseq-clip.readthedocs.io/en/latest/index.html 

BugReports: https://github.com/EMBL-Hentze-group/htseq-clip/issues

installation: `pip install htseq-clip`

Copyright (c) 2020 Sudeep Sahadevan, Marko Fritz, Nadia Ashraf and Thomas Schwarzl*

*Project lead: Thomas Schwarzl

[Matthias Hentze](https://www.embl.de/research/units/directors_research/hentze/index.html) and    
[Wolfgang Huber](https://www.embl.de/research/units/genome_biology/huber/index.html) Labs,   
[EMBL, Heidelberg](https://www.embl.de/). 